/*
**++
**  FACILITY:  {@tbs@}
**
**  MODULE DESCRIPTION:
**
**      This program patches the debug bit in the image header.
**
**  AUTHORS:
**
**      Jeff Zeeb
**
**  CREATION DATE:  August 1992
**
**  DESIGN ISSUES:
**
**      {@tbs@}
**
**  MODIFICATION HISTORY:
**
**      {@tbs@}...
**--
*/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>

main (int argc, char *argv[])
{
    FILE    *inf;
    fpos_t  pos;
    unsigned char   buffer[512];
    int     offset = 0x50;
    int     turn_off = 1;

    if (argc != 3 && argc != 4) {
        fprintf(stderr, "Syntax: image_file {off | on} [alpha | vax]\n");
        exit(EXIT_FAILURE);
    }

    if (strcmp(argv[2], "off") == 0)
        turn_off = 1;
    else if (strcmp(argv[2], "on") == 0)
        turn_off = 0;
    else {
        fprintf(stderr, "Specify OFF or ON as the second parameter\n");
        exit(EXIT_FAILURE);
    }

    /*
    **  Set the proper offset for the platform of interest.
    */
    if (argc == 4) {
        if (strcmp(argv[3], "vax") == 0)
            offset = 0x20;
        else if (strcmp(argv[3], "alpha") == 0)
            offset = 0x50;
        else {
            fprintf(stderr, "Unknown system type: %s\n", argv[3]);
            exit(EXIT_FAILURE);
        }
    }

    if ((inf = fopen(argv[1], "r+b")) == NULL) {
        fprintf(stderr, "Unable to open %s\n", argv[1]);
        exit(EXIT_FAILURE);
    }

    fgetpos(inf, &pos);
    if (fread(buffer, sizeof(buffer), 1, inf) != 1) {
        fprintf(stderr, "Error reading %s\n", argv[1]);
        exit(EXIT_FAILURE);
    }

    printf("Old value: %x\n", buffer[offset]);
    if (turn_off)
        buffer[offset] &= 0xFE;
    else
        buffer[offset] |= 0x1;
    printf("New value: %x\n", buffer[offset]);

    fsetpos(inf, &pos);
    if (fwrite(buffer, sizeof(buffer), 1, inf) != 1) {
        fprintf(stderr, "Error writing %s\n", argv[1]);
        exit(EXIT_FAILURE);
    }

    fclose(inf);
}

